==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/QrtzCronTriggersKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaTriggerow;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzCronTriggersKey extends GenericDPSObject {
    /**
     * QRTZ_CRON_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String schedName;

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String triggerName;

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private GrupaTriggerow triggerGroup;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_CRON_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:40
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_CRON_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTriggerName() {
        return triggerName;
    }

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     *
     * @param triggerName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTriggerName(String triggerName) {
        this.triggerName = triggerName == null ? null : triggerName.trim();
    }

    /**
     * @return QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public GrupaTriggerow getTriggerGroup() {
        return triggerGroup;
    }

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     *
     * @param triggerGroup
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTriggerGroup(GrupaTriggerow triggerGroup) {
        this.triggerGroup = triggerGroup;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzCronTriggersKey other = (QrtzCronTriggersKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getTriggerName() == null ? other.getTriggerName() == null : this.getTriggerName().equals(other.getTriggerName()))
            && (this.getTriggerGroup() == null ? other.getTriggerGroup() == null : this.getTriggerGroup().equals(other.getTriggerGroup()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getTriggerName() == null) ? 0 : getTriggerName().hashCode());
        result = prime * result + ((getTriggerGroup() == null) ? 0 : getTriggerGroup().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", triggerName=").append(triggerName);
        sb.append(", triggerGroup=").append(triggerGroup);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/QrtzCronTriggersKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaTriggerow;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzCronTriggersKey extends GenericDPSObject {
    /**
     * QRTZ_CRON_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String schedName;

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String triggerName;

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private GrupaTriggerow triggerGroup;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_CRON_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:44
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_CRON_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTriggerName() {
        return triggerName;
    }

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_NAME
     *
     * @param triggerName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTriggerName(String triggerName) {
        this.triggerName = triggerName == null ? null : triggerName.trim();
    }

    /**
     * @return QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public GrupaTriggerow getTriggerGroup() {
        return triggerGroup;
    }

    /**
     * QRTZ_CRON_TRIGGERS.TRIGGER_GROUP
     *
     * @param triggerGroup
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTriggerGroup(GrupaTriggerow triggerGroup) {
        this.triggerGroup = triggerGroup;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzCronTriggersKey other = (QrtzCronTriggersKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getTriggerName() == null ? other.getTriggerName() == null : this.getTriggerName().equals(other.getTriggerName()))
            && (this.getTriggerGroup() == null ? other.getTriggerGroup() == null : this.getTriggerGroup().equals(other.getTriggerGroup()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getTriggerName() == null) ? 0 : getTriggerName().hashCode());
        result = prime * result + ((getTriggerGroup() == null) ? 0 : getTriggerGroup().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", triggerName=").append(triggerName);
        sb.append(", triggerGroup=").append(triggerGroup);
        sb.append("]");
        return sb.toString();
    }
}
